@@ -30,7 +30,10 @@ def stringify(
         return _clean_empty(value)
     if isinstance(value, (date, datetime)):
         return value.isoformat()
-    elif isinstance(value, (float, Decimal)):
+    elif isinstance(value, float):
+        # Avoid trailing zeros and limit to 3 decimal places:
+        return format(value, ".3f").rstrip("0").rstrip(".")
+    elif isinstance(value, Decimal):
         return Decimal(value).to_eng_string()
     elif isinstance(value, bytes):
         if encoding is None:
